@@ -33,53 +33,33 @@ G_BEGIN_DECLS
 
 #define GPK_SETTINGS_SCHEMA				"org.gnome.packagekit"
 #define GPK_SETTINGS_AUTOCOMPLETE			"autocomplete"
-#define GPK_SETTINGS_AUTO_UPDATE			"auto-update"
-#define GPK_SETTINGS_BANNED_FIRMWARE			"banned-firmware"
 #define GPK_SETTINGS_CATEGORY_GROUPS			"category-groups"
-#define GPK_SETTINGS_CONNECTION_USE_MOBILE		"connection-use-mobile"
-#define GPK_SETTINGS_CONNECTION_USE_WIFI		"connection-use-wifi"
 #define GPK_SETTINGS_DBUS_DEFAULT_INTERACTION		"dbus-default-interaction"
 #define GPK_SETTINGS_DBUS_ENFORCED_INTERACTION		"dbus-enforced-interaction"
 #define GPK_SETTINGS_ENABLE_AUTOREMOVE			"enable-autoremove"
-#define GPK_SETTINGS_ENABLE_CHECK_FIRMWARE		"enable-check-firmware"
-#define GPK_SETTINGS_ENABLE_CHECK_HARDWARE		"enable-check-hardware"
 #define GPK_SETTINGS_ENABLE_CODEC_HELPER		"enable-codec-helper"
 #define GPK_SETTINGS_ENABLE_FONT_HELPER			"enable-font-helper"
 #define GPK_SETTINGS_ENABLE_MIME_TYPE_HELPER		"enable-mime-type-helper"
 #define GPK_SETTINGS_FILTER_ARCH			"filter-arch"
 #define GPK_SETTINGS_FILTER_BASENAME			"filter-basename"
 #define GPK_SETTINGS_FILTER_NEWEST			"filter-newest"
-#define GPK_SETTINGS_FORCE_GET_UPDATES_LOGIN		"force-get-updates-login"
-#define GPK_SETTINGS_FREQUENCY_GET_UPDATES		"frequency-get-updates"
-#define GPK_SETTINGS_FREQUENCY_GET_UPGRADES		"frequency-get-upgrades"
-#define GPK_SETTINGS_FREQUENCY_REFRESH_CACHE		"frequency-refresh-cache"
 #define GPK_SETTINGS_IGNORED_DBUS_REQUESTS		"ignored-dbus-requests"
-#define GPK_SETTINGS_IGNORED_DEVICES			"ignored-devices"
-#define GPK_SETTINGS_IGNORED_MESSAGES			"ignored-messages"
-#define GPK_SETTINGS_INSTALL_ROOT			"install-root"
-#define GPK_SETTINGS_MEDIA_REPO_FILENAMES		"media-repo-filenames"
-#define GPK_SETTINGS_NOTIFY_AVAILABLE			"notify-available"
-#define GPK_SETTINGS_NOTIFY_COMPLETED			"notify-complete"
-#define GPK_SETTINGS_NOTIFY_CRITICAL			"notify-critical"
-#define GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES		"notify-distro-upgrades"
-#define GPK_SETTINGS_NOTIFY_ERROR			"notify-errors"
-#define GPK_SETTINGS_NOTIFY_MESSAGE			"notify-message"
 #define GPK_SETTINGS_NOTIFY_MOBILE_CONNECTION		"notify-mobile-connection"
-#define GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE		"notify-update-complete"
-#define GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE_RESTART	"notify-update-complete-restart"
-#define GPK_SETTINGS_NOTIFY_UPDATE_FAILED		"notify-update-failed"
-#define GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY		"notify-update-not-battery"
-#define GPK_SETTINGS_NOTIFY_UPDATE_STARTED		"notify-update-started"
 #define GPK_SETTINGS_ONLY_NEWEST			"only-newest"
 #define GPK_SETTINGS_REPO_SHOW_DETAILS			"repo-show-details"
 #define GPK_SETTINGS_SCROLL_ACTIVE			"scroll-active"
 #define GPK_SETTINGS_SEARCH_MODE			"search-mode"
-#define GPK_SETTINGS_SESSION_STARTUP_TIMEOUT		"session-startup-timeout"
 #define GPK_SETTINGS_SHOW_ALL_PACKAGES			"show-all-packages"
 #define GPK_SETTINGS_SHOW_COPY_CONFIRM			"show-copy-confirm"
 #define GPK_SETTINGS_SHOW_DEPENDS			"show-depends"
-#define GPK_SETTINGS_UPDATE_BATTERY			"update-battery"
-#define GPK_SETTINGS_WATCH_ACTIVE_TRANSACTIONS		"watch-active-transactions"
+
+#define GSD_SETTINGS_SCHEMA				"org.gnome.settings-daemon.plugins.updates"
+#define GSD_SETTINGS_AUTO_UPDATE_TYPE			"auto-update-type"
+#define GSD_SETTINGS_CONNECTION_USE_MOBILE		"connection-use-mobile"
+#define GSD_SETTINGS_FREQUENCY_GET_UPDATES		"frequency-get-updates"
+#define GSD_SETTINGS_FREQUENCY_GET_UPGRADES		"frequency-get-upgrades"
+#define GSD_SETTINGS_FREQUENCY_REFRESH_CACHE		"frequency-refresh-cache"
+#define GSD_SETTINGS_UPDATE_BATTERY			"update-battery"
 
 #define GPK_BUGZILLA_URL			"https://bugs.freedesktop.org/"
 
